@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # -------------------------------------------------------
-# $Header: /home/cvs/dobackup/dobackup.pl,v 4.34 2005/05/31 18:08:01 imorgan Exp $
+# $Header: /home/cvs/dobackup/dobackup.pl,v 4.35 2006/03/07 17:31:37 imorgan Exp $
 # -------------------------------------------------------
 #
 # Copyright 1997-2004 Webcon, Inc.
@@ -238,7 +238,7 @@ sub ShowSyntax {
   my($temp)=('');
 
   print "\nUsage: $ExecutableName <options>\n";
-  $temp = '$Revision: 4.34 $';
+  $temp = '$Revision: 4.35 $';
   ($temp) = ( $temp =~ /^\$Revision\:\ (.*?)\ \$$/ );
   print 'Version: ',"$temp\n";
   print <<EOF;
@@ -1041,7 +1041,7 @@ sub PerformBackup{
 
 sub Cleanup{
   my($temp)=0;
-  my($temp2)=0;
+  my($IgnoreFreeSpace)=0;
   my($Usage)=0;
   my($UsageExact)=0;
   my($LastSize)=0;
@@ -1055,7 +1055,7 @@ sub Cleanup{
   open (MAILTHIS, "|$MailProg $BackupAdministrator");
   print MAILTHIS "To: $BackupAdministrator\nSubject: $Host ",($Debug?"Debug-mode":"Automated")," Backup Summary\n\n";
 
-  $temp = '$Revision: 4.34 $';
+  $temp = '$Revision: 4.35 $';
   ($temp) = ( $temp =~ /^\$Revision\:\ (.*?)\ \$$/ );
 
   print MAILTHIS "This is an automated backup report from $ExecutableName v$temp\n\n";
@@ -1110,7 +1110,13 @@ sub Cleanup{
   $Usage =~ s/\b(\d+)\w*M\b/$1 MiB/g;
   $Usage =~ s/\b(\d+)\w*G\b/$1 GiB/g;
   ($Mode{$Host} eq 'Tape') && print MAILTHIS 'Current Tape Position: ' , $Usage , "\n";
-  ($Mode{$Host} eq 'Disk' || $Mode{$Host} eq 'Filesystem') && print MAILTHIS 'Space Remaining: ' , $Usage , "\n";
+
+  $IgnoreFreeSpace = $IniConfig->val("MediaSet=$MediaSet{$Host}",'IgnoreFreeSpace');
+  if ( ! defined($IgnoreFreeSpace) ) {
+    $IniConfig->newval("MediaSet=$MediaSet{$Host}",'IgnoreFreeSpace',0);
+    $IgnoreFreeSpace=0;
+  }
+  ($Mode{$Host} eq 'Disk' || $Mode{$Host} eq 'Filesystem') && print MAILTHIS 'Space Remaining: ' , $IgnoreFreeSpace?'Ignored':$Usage , "\n";
 
   # write LastSizeBytes to lastsizefull if in full mode
   if ($opt_fullbackup || $Timestamp{$Host} == 0) {
@@ -1128,13 +1134,15 @@ sub Cleanup{
   $Debug && print "Full: $LastSizeFull\n";
   $Debug && print "Last: $LastSizeBytes\n";
 
-  if ( $UsageExact < $LastSizeFull ) {
-   $Debug && print "WARNING: free space may be to low for next FULL backup\n";
-   print MAILTHIS "\nWARNING: Space Remaining may be too low for the next FULL backup to complete!\n";
-  }
-  if ( $UsageExact < $LastSizeBytes ) {
-   $Debug && print "WARNING: free space may be to low for next backup\n";
-   print MAILTHIS "\nWARNING: Space Remaining may be too low for the next regular backup to complete!\n";
+  if (! $IgnoreFreeSpace) {
+    if ( $UsageExact < $LastSizeFull ) {
+     $Debug && print "WARNING: free space may be to low for next FULL backup\n";
+     print MAILTHIS "\nWARNING: Space Remaining may be too low for the next FULL backup to complete!\n";
+    }
+    if ( $UsageExact < $LastSizeBytes ) {
+     $Debug && print "WARNING: free space may be to low for next backup\n";
+     print MAILTHIS "\nWARNING: Space Remaining may be too low for the next regular backup to complete!\n";
+    }
   }
 
   close(MAILTHIS);
